<!-- DOC_TYPE: CONCEPT -->

# Документация По Project Output Переехала

Подробная документация по структуре generated project теперь относится к `codex-django-cli`.

Используйте runtime-гайды из этого репозитория, когда вы уже находитесь внутри generated project и хотите понять, как reusable-модули `codex_django.*` встраиваются в эту структуру.
